ledger.PartnerVouchers (Vouchers) — amici1

# `ledger.PartnerVouchers` (Vouchers)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<django.db.models.fields.related.ForeignKey: journal>`

- `<django.db.models.fields.DateField: entry_date>`

- `<django.db.models.fields.DateField: voucher_date>`

- `<django.db.models.fields.related.ForeignKey: accounting_period>`

- `<django.db.models.fields.IntegerField: number>`

- `<django.db.models.fields.CharField: narration>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- Create (submit_insert) : Create the record and open a detail window on it

- ⚇ (duplicate) : Duplicate the selected row.

- Delete (delete_selected) : Delete this record

- Upload files (show_uploads) : Show uploads in a grid table.

- Check data (check_data) : See `<lino.modlib.checkdata.models.UpdateProblemsByController check_data ('Check data')>`.

- Fix data problems (fix_problems) : See `<lino.modlib.checkdata.models.FixProblemsByController fix_problems ('Fix data problems')>`.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

Filter parameters

- `<lino.core.fields.DummyField object at 0x7fc81e005ef0>`

- `<lino.core.choicelists.ChoiceListField: state>`

- `<django.db.models.fields.related.ForeignKey: partner>`

- `<lino.core.choicelists.ChoiceListField: cleared>`

- `<django.db.models.fields.related.ForeignKey: year>`

- `<django.db.models.fields.related.ForeignKey: journal>`

- `<django.db.models.fields.related.ForeignKey: start_period>`

- `<django.db.models.fields.related.ForeignKey: end_period>`

- `<django.db.models.fields.related.ForeignKey: user>`

## Filter parameters